@@ -1,5 +1,13 @@
 #!/usr/bin/env python
 
+""" SOCKS5 server
+
+    Parameters:
+        --host, -H: ip/host to listen on for SOCKS5 server
+        --port, -P: port to listen on
+        --verbose, -V: increase verbosity
+"""
+
 import asyncio
 import argparse
 import logging
@@ -11,7 +19,7 @@ async def main(args, loop):
     server = await loop.create_server(
          lambda: Socks5Protocol(loop=loop),
          host=args.host, port=args.port, reuse_address=True, start_serving=True)
-    logger.info(f"Socks server listening on {args.host}:{args.port}.")
+    logger.info(f"Socks5 server listening on {args.host}:{args.port}.")
     
     await server.wait_closed()
 
@@ -38,3 +46,5 @@ if __name__ == "__main__":
 
     loop = asyncio.get_event_loop()
     loop.run_until_complete(main(args, loop))
+
+__all__ = []
